/*************************************************
 *
 * $GAMGI/src/gtk/atom/gamgi_gtk_atom_property.h
 *
 * Copyright (C) 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static void static_remove (GtkWidget *widget, void *data);

static int static_delete (GtkWidget *widget,
GdkEventButton *event, void *data);

static void static_mass_select (GtkWidget *widget, void *data);

static void static_radius_select (GtkWidget *widget, void *data);

static void static_charge_select (GtkWidget *widget, void *data);

static void static_mass_create (GtkWidget *widget, void *data);

static void static_radius_create (GtkWidget *widget, void *data);

static void static_charge_create (GtkWidget *widget, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_atom_property_mass (GtkWidget *widget, void *data);

void gamgi_gtk_atom_property_radius (GtkWidget *widget, void *data);

void gamgi_gtk_atom_property_charge (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Under development.

 *************
 * Rationale *
 *************/
